@@ -1,18 +1,14 @@
 import threading
 from typing import (
     Any, Dict, Iterable, List, NewType, 
-    Optional,  Set, Tuple, Union, TYPE_CHECKING
+    Set, Tuple, Union, TYPE_CHECKING
 )
-import typing
 from uuid import uuid4
 
-from . import utils
-from .utils import arguments
 from .chart_elements import (
-    ChartClass, 
-    ChartStructline, ChartDifferential, ChartExtension, ChartEdge
+    ChartClass, ChartClassStyle,
+    ChartStructline, ChartDifferential, ChartExtension, ChartEdge, ChartEdgeStyle
 )
-from .messages import *
 from .infinity import INFINITY
 
 if not TYPE_CHECKING:
@@ -64,6 +60,11 @@ class SseqChart:
         self._x_range = (0, 10)
         self._y_range = (0, 10)
   
+        self._default_class_style = ChartClassStyle()
+        self._default_structline_style = ChartEdgeStyle()
+        self._default_differential_style = ChartEdgeStyle()
+        self._default_extension_style = ChartEdgeStyle()
+
         self._page_list_lock = threading.Lock()
         self._classes : Dict[str, ChartClass] = {}
         self._edges : Dict[str, ChartEdge] = {}
@@ -87,9 +88,6 @@ class SseqChart:
         if len(self.y_projection) != self.num_gradings:
             raise TypeError(f"y_projection has length {len(self.y_projection)} not equal to num_gradings {self.num_gradings}")
         
-        # for e in self.page_list:
-        #     if 
-
         for c in self.classes_iter:
             pass
 
@@ -198,6 +196,7 @@ class SseqChart:
         assert len(degree) == self.num_gradings
         idx = len(self._classes_by_degree.get(degree, []))
         c = ChartClass(degree, idx)
+        c.set_style(slice(None), self.default_class_style)
         self._commit_class(c)
         return c
 
@@ -231,12 +230,16 @@ class SseqChart:
         """
         source = self._normalize_class_argument(source_arg)
         target = self._normalize_class_argument(target_arg)
-        e = ChartDifferential(page=page, source_uuid=source.uuid, target_uuid=target.uuid)
-        self._edges[e.uuid] = e
         if auto:
+            # TODO: Does any sort of checking belong here?
+            # if source._max_page < page:
+            
             source._max_page = page
             target._max_page = page
-            self.add_page_range(page,page)
+            # self.add_page_range(page,page)
+        e = ChartDifferential(page=page, source_uuid=source.uuid, target_uuid=target.uuid)
+        e.set_style(self._default_differential_style)
+        self._edges[e.uuid] = e
         self._commit_edge(e)        
         return e
 
@@ -254,6 +257,7 @@ class SseqChart:
         source = self._normalize_class_argument(source_arg)
         target = self._normalize_class_argument(target_arg)
         e = ChartStructline(source_uuid=source.uuid, target_uuid=target.uuid)
+        e.set_style(slice(None), self._default_structline_style)
         self._commit_edge(e)
         return e
 
@@ -269,6 +273,7 @@ class SseqChart:
         source = self._normalize_class_argument(source_arg)
         target = self._normalize_class_argument(target_arg)
         e = ChartExtension(source_uuid=source.uuid, target_uuid=target.uuid)
+        e.set_style(self._default_extension_style)
         self._commit_edge(e)
         return e
     
@@ -308,11 +313,9 @@ class SseqChart:
     def _add_class_to_delete(self, c : ChartClass):
         self._add_delete_message(c)
 
-
     def _add_edge_to_update(self, e : ChartEdge):
         self._add_update_message(e)
 
-
     def _add_edge_to_delete(self, e : ChartEdge):
         self._add_delete_message(e)
 
@@ -367,9 +370,6 @@ class SseqChart:
             )
         )
 
-    def _add_setting_message(self):
-        pass
-
     async def update_a(self):
         """ Update the display. This will send a message to the display instructing it about how to 
             "catch up with" the current state of the SseqChart in the Python runtime.
@@ -428,6 +428,43 @@ class SseqChart:
             raise TypeError(f'Argument to "classes_in_degree" must have length "num_gradings" = {self.num_gradings}')
         return self._classes_by_degree.get(args, [])
 
+    @property
+    def default_class_style(self) -> ChartClassStyle:
+        """ The default style for all new classes. Changes to the default will not affect existing classes. """
+        return self._default_class_style
+
+    @default_class_style.setter
+    def default_class_style(self, value : ChartClassStyle):
+        self._default_class_style = value
+
+    @property
+    def default_structline_style(self) -> ChartEdgeStyle:
+        """ The default style for all new structlines. Changes to the default will not affect existing structlines. """
+        return self._default_structline_style
+
+    @default_structline_style.setter
+    def default_structline_style(self, value : ChartEdgeStyle):
+        self._default_structline_style = value
+
+    @property
+    def default_differential_style(self) -> ChartEdgeStyle:
+        """ The default style for all new differentials. Changes to the default will not affect existing differentials. """
+        return self._default_differential_style
+
+    @default_differential_style.setter
+    def default_differential_style(self, value : ChartEdgeStyle):
+        self._default_differential_style = value
+
+    @property
+    def default_extension_style(self) -> ChartEdgeStyle:
+        """ The default style for all new extensions. Changes to the default will not affect existing extensions. """
+        return self._default_extension_style
+
+    @default_extension_style.setter
+    def default_extension_style(self, value : ChartEdgeStyle):
+        self._default_extension_style = value
+
+
     @property
     def x_min(self):
         """ The minimum x view extent. This represents the minimum x value that is possible to look at with the display.
